---
title: JavaScript — Dynamic client-side scripting
slug: Learn/JavaScript
tags:
  - Beginner
  - CodingScripting
  - JavaScript
  - JavaScripting beginner
  - Landing
  - Module
  - Topic
  - l10n:priority
---
{{LearnSidebar}}

{{Glossary("JavaScript")}} is a programming language that allows you to implement complex things on web pages. Every time a web page does more than just sit there and display static information for you to look at—displaying timely content updates, interactive maps, animated 2D/3D graphics, scrolling video jukeboxes, or more—you can bet that JavaScript is probably involved.

> **Callout:**
>
> #### Looking to become a front-end web developer?
>
> We have put together a course that includes all the essential information you need to
> work towards your goal.
>
> [**Get started**](/en-US/docs/Learn/Front-end_web_developer)

## Prerequisites

JavaScript is arguably more difficult to learn than related technologies such as [HTML](/en-US/docs/Learn/HTML) and [CSS](/en-US/docs/Learn/CSS). Before attempting to learn JavaScript, you are strongly advised to get familiar with at least these two technologies first, and perhaps others as well. Start by working through the following modules:

- [Getting started with the Web](/en-US/docs/Learn/Getting_started_with_the_web)
- [Introduction to HTML](/en-US/docs/Learn/HTML/Introduction_to_HTML)
- [Introduction to CSS](/en-US/docs/Learn/CSS/First_steps)

Having previous experience with other programming languages might also help.

After getting familiar with the basics of JavaScript, you should be in a position to learn about more advanced topics, for example:

- JavaScript in depth, as taught in our [JavaScript guide](/en-US/docs/Web/JavaScript/Guide)
- [Web APIs](/en-US/docs/Web/API)

## Modules

> **Callout:**
>
> **Our policy on modern JavaScript**
>
> JavaScript is an actively evolving language and has changed greatly over the years. In particular, the 6th edition of the language (sometimes known as ECMAScript 2015 or ES6), introduced in 2015, added many new features. At the same time, to maintain backwards compatibility with older websites, old features of the language have been retained, even when they are no longer considered good practice.
>
> We think that the features added to JavaScript in ECMAScript 2015 and subsequent versions enable developers to write more readable, reliable, and expressive code, and that it's important to learn about them.
>
> The features we teach in this course are stable and have been supported by all major browsers for several years. You're only likely to have trouble using them in obsolete browsers, in particular Internet Explorer. If you do need to support obsolete browsers, we recommend using a tool like [Babel](https://babeljs.io/), which enables you to write modern JavaScript but have it run in browsers that don't support it.

This topic contains the following modules, in a suggested order for working through them.

- [JavaScript first steps](/en-US/docs/Learn/JavaScript/First_steps)
  - : In our first JavaScript module, we first answer some fundamental questions such as "what is JavaScript?", "what does it look like?", and "what can it do?", before moving on to taking you through your first practical experience of writing JavaScript. After that, we discuss some key JavaScript features in detail, such as variables, strings, numbers and arrays.
- [JavaScript building blocks](/en-US/docs/Learn/JavaScript/Building_blocks)
  - : In this module, we continue our coverage of all JavaScript's key fundamental features, turning our attention to commonly-encountered types of code block such as conditional statements, loops, functions, and events. You've seen this stuff already in the course, but only in passing — here we'll discuss it all explicitly.
- [Introducing JavaScript objects](/en-US/docs/Learn/JavaScript/Objects)
  - : In JavaScript, most things are objects, from core JavaScript features like strings and arrays to the browser APIs built on top of JavaScript. You can even create your own objects to encapsulate related functions and variables into efficient packages. The object-oriented nature of JavaScript is important to understand if you want to go further with your knowledge of the language and write more efficient code, therefore we've provided this module to help you. Here we teach object theory and syntax in detail, look at how to create your own objects, and explain what JSON data is and how to work with it.
- [Asynchronous JavaScript](/en-US/docs/Learn/JavaScript/Asynchronous)
  - : In this module we take a look at asynchronous JavaScript, why it is important, and how it can be used to effectively handle potential blocking operations such as fetching resources from a server.
- [Client-side web APIs](/en-US/docs/Learn/JavaScript/Client-side_web_APIs)
  - : When writing client-side JavaScript for web sites or applications, you won't go very far before you start to use APIs — interfaces for manipulating different aspects of the browser and operating system the site is running on, or even data from other web sites or services. In this module we will explore what APIs are, and how to use some of the most common APIs you'll come across often in your development work.

## Solving common JavaScript problems

[Use JavaScript to solve common problems](/en-US/docs/Learn/JavaScript/Howto) provides links to sections of content explaining how to use JavaScript to solve very common problems when creating a webpage.

## See also

- [JavaScript on MDN](/en-US/docs/Web/JavaScript)
  - : The main entry point for core JavaScript documentation on MDN — this is where you'll find extensive reference docs on all aspects of the JavaScript language, and some advanced tutorials aimed at experienced JavaScripters.
- [Learn JavaScript](https://learnjavascript.online/)
  - : An excellent resource for aspiring web developers — Learn JavaScript in an interactive environment, with short lessons and interactive tests, guided by automated assessment. The first 40 lessons are free, and the complete course is available for a small one-time payment.
- [Coding math](https://www.youtube.com/user/codingmath)
  - : An excellent series of video tutorials to teach the math you need to understand to be an effective programmer, by [Keith Peters](https://twitter.com/bit101).
