---
title: Introduction to Web development
slug: Web/Guide/Introduction_to_Web_development
tags:
  - Beginner
  - CSS
  - CodingScripting
  - Development
  - HTML
  - JavaScript
  - Web
---
Whether you're just getting started with Web development, or are just expanding your horizons into new realms of Web awesomeness, the links here should help you get started.

For another (overlapping) set of links to learning resources, see the [MDN Learning](/en-US/docs/Learn) pages.

## Documentation topics

### HTML

- [The basics of Hypertext Mark-up Language (HTML)](https://www.w3.org/community/webed/wiki/The_basics_of_HTML) — what exactly is HTML?
- [Basic structure of a web page](https://reference.sitepoint.com/html/page-structure) — the doctype and document 'tree'
- [Fundamental HTML elements](https://reference.sitepoint.com/html/elements) — structural, head, list, form elements and more, explained by category.
- [HTML beginners tutorial](https://htmldog.com/guides/htmlbeginner/) — a tutorial and exercise that recap and take you through the basics you've learned above.
- [HTML elements reference guide](/en-US/docs/Web/HTML/Element) — a comprehensive guide to HTML elements with details on how browsers support them

### CSS

- [Getting started with CSS](/en-US/docs/Learn/CSS/First_steps) — an absolute beginners guide to CSS covers basic concepts and fundamentals
- [CSS reference guide](/en-US/docs/Web/CSS/Reference) — a complete guide to CSS with details on the level of Gecko/Firefox support for each.
- [The W3C introduction to styling with CSS](https://www.w3.org/MarkUp/Guide/Style) — a brief guide to styling web pages for beginners.
- [Common CSS questions](/en-US/docs/Learn/CSS/Howto/CSS_FAQ) — common questions and answers for beginners
- [Intermediate CSS concepts](http://www.html.net/tutorials/css/) — grouping, pseudo-classes and more.

### JavaScript

#### Beginning

- [Getting started with JavaScript](/en-US/docs/Learn/Getting_started_with_the_web/JavaScript_basics) — what is JavaScript and how can it help you?
- [JavaScript reference guide](/en-US/docs/Web/JavaScript/Guide) — a comprehensive, regularly updated guide to JavaScript for all levels of learning from beginner to advanced.
- [Crockford on JavaScript](https://www.youtube.com/playlist?list=PL7664379246A246CB) — an in-depth video series on the JavaScript language.
- [Eloquent JavaScript](https://eloquentjavascript.net/contents.html) — a comprehensive guide to intermediate and advanced JavaScript methodologies

#### Intermediate

- [A re-introduction to JavaScript](/en-US/docs/Web/JavaScript/A_re-introduction_to_JavaScript) — a recap on the JavaScript programming language aimed at intermediate-level developers
- [Essential JavaScript design patterns](https://www.addyosmani.com/resources/essentialjsdesignpatterns/book/) — an introduction to essential JavaScript design patterns
- [Introduction to object-oriented JavaScript](/en-US/docs/Learn/JavaScript/Objects) — learn about the JavaScript object model.
- [Christian Heilmann's JavaScript best practices](https://dev.opera.com/articles/view/javascript-best-practices/) — learn about some of the obvious and (not so) obvious best practices when writing JavaScript.

#### Advanced

- [Learning advanced JavaScript](http://ejohn.org/apps/learn/) — John Resig's guide to advanced JavaScript
- [Crockford on Advanced JavaScript](https://uk.video.yahoo.com/watch/111585/1027823) — a three part video series on advanced JavaScript concepts
- [JavaScript Garden](https://bonsaiden.github.com/JavaScript-Garden/) — Documentation of the most quirky parts of JavaScript.

## Resources

- [W3C Web Education Community Group Wiki](https://www.w3.org/community/webed/wiki/Main_Page)
  - : Covers web design, HTML and HTML5, CSS, JavaScript and accessibility. This is a good starting point for beginners wishing to learn web development fundamentals across a number of areas.
- [SitePoint](https://reference.sitepoint.com/)
  - : A reliable reference site for learning HTML, CSS and JavaScript which also mentions feature support across different browsers and known browser bugs.
- [HTMLDog](https://htmldog.com/)
  - : An excellent and comprehensive reference site on HTML and CSS for beginners.
- [Google's HTML, CSS, and Javascript from the Ground Up](https://code.google.com/edu/submissions/html-css-javascript/)
  - : These easily digestible video tutorials from Google's expert web developers cover the basics of HTML, CSS and JavaScript.
- [CSSTutorial.net Beginner Tutorials](https://www.csstutorial.net/)
  - : A broad range of useful text and video tutorials that cover the basics through to intermediate aspects of CSS.
- [Tizag CSS Tutorials](http://www.tizag.com/cssT/)
  - : An easy-to-follow reference for those wishing to learn CSS through short, concise tutorials.
- [jQuery Fundamentals](http://jqfundamentals.com/)
  - : An open-source reference book featuring detailed introductions to both JavaScript and JQuery for beginners.
- [JavaScript From Null: A Video Series](https://net.tutsplus.com/tutorials/javascript-ajax/javascript-from-null-video-series/)
  - : A video series on JavaScript for absolute beginners looking for more 'visual'-based learning
