---
title: Web technology for developers
slug: Web
tags:
  - Landing
  - Web
---
The open Web presents incredible opportunities for developers. To take full advantage of these technologies, you need to know how to use them. Below you'll find links to our Web technology documentation.

## Documentation for Web developers

- [Web Developer Guide](/en-US/docs/Web/Guide)
  - : The Web Developer Guide provides useful how-to content to help you actually use Web technologies to do what you want or need to do.
- [Tutorials for Web developers](/en-US/docs/Web/Tutorials)
  - : Tutorials to take you step-by-step through learning HTML, CSS, JavaScript, and Web APIs.
- [Accessibility](/en-US/docs/Web/Accessibility)
  - : Enabling as many people as possible to use Web sites, even when those people's abilities are limited in some way.
- [Performance](/en-US/docs/Web/Performance)
  - : Making content as available and interactive as possible, as soon as possible.
- [Security](/en-US/docs/Web/Security)
  - : Protecting users from data leaks and data theft, side-channel attacks, and attacks such as cross-site scripting, content injection, and click-jacking.

## Web technology references

- [Web APIs](/en-US/docs/Web/API)
  - : JavaScript programming APIs you can use to build apps on the Web.
- [HTML](/en-US/docs/Web/HTML)
  - : HTML provides the fundamental building blocks for structuring Web documents and apps.
- [CSS](/en-US/docs/Web/CSS)
  - : Cascading Style Sheets are used to describe the appearance of Web documents and apps.
- [JavaScript](/en-US/docs/Web/JavaScript)
  - : JavaScript is the Web’s native programming language.
- [WebAssembly](/en-US/docs/WebAssembly)
  - : WebAssembly allows programs written in C, C++, Rust, Swift, C#, Go, and more to run on the Web.
- [Events](/en-US/docs/Web/Events)
  - : Events are what you build Web apps to react to; for example, when a Web page finishes loading, or a user selects something, presses a key, resizes a window, submits a form, or pauses a video.
- [HTTP](/en-US/docs/Web/HTTP)
  - : HTTP is the fundamental Internet protocol for fetching documents, stylesheets, scripts, images, videos, fonts, and other resources over the Web — and for sending data back to Web servers.
- [Media](/en-US/docs/Web/Media)
  - : Formats, codecs, protocols, APIs, and techniques for embedding and streaming video, audio, and image content in Web documents and apps.
- [SVG](/en-US/docs/Web/SVG)
  - : Scalable Vector Graphics let you to create images that scale smoothly to any size.
- [MathML](/en-US/docs/Web/MathML)
  - : MathML lets you display complex mathematical notation on the Web.
- [Web Components](/en-US/docs/Web/Web_Components)
  - : Web Components are custom elements that you can define and reuse in your Web apps.
- [WebDriver](/en-US/docs/Web/WebDriver)
  - : WebDriver is a browser-automation mechanism for remotely controlling a browser by emulating the actions of a real person using the browser. It’s widely used for cross-browser testing of Web apps.
- [Web Extensions](/en-US/docs/Mozilla/Add-ons/WebExtensions)
  - : Web Extensions are a way for you to give users enhanced capabilities in their browsers — for doing things such as blocking ads and other content, customizing the appearance of pages, and more.
- [Web App Manifests](/en-US/docs/Web/Manifest)
  - : Web App Manifests let you enable users to install Web apps to their device home screens, with aspects such as portrait/landscape screen orientation and display mode (e.g., full screen) pre-set.
- [Progressive Web Apps (PWAs)](/en-US/docs/Web/Progressive_web_apps)
  - : Progressive Web Apps provide a user experience similar to native mobile apps.

## Developer tools documentation

- [Firefox Developer Tools](/en-US/docs/Tools)
  - : Documentation for the set of web-developer tools built into Firefox.
- [Chrome DevTools](https://developer.chrome.com/docs/devtools/)
  - : Documentation for the set of web-developer tools built into Chrome.
- [Safari Web Inspector](https://webkit.org/web-inspector/)
  - : Documentation for the set of web-developer tools built into Safari.
- [Edge DevTools](https://docs.microsoft.com/en-us/microsoft-edge/devtools-guide-chromium/)
  - : Documentation for the set of web-developer tools built into Edge.
