---
title: About the JavaScript reference
slug: Web/JavaScript/Reference/About
tags:
  - Guide
  - JavaScript
---
{{JsSidebar}}

The JavaScript reference serves as a repository of facts about the JavaScript language. The entire language is described here in detail. As you write JavaScript code, you'll refer to these pages often (thus the title "JavaScript reference"). If you're learning JavaScript, or need help understanding some of its capabilities or features, check out the [JavaScript guide](/en-US/docs/Web/JavaScript/Guide).

The JavaScript language is intended to be used within some larger environment, be it a browser, server-side scripts, or similar. For the most part, this reference attempts to be environment-agnostic and does not target a web browser environment.

## Where to find JavaScript information

JavaScript documentation of core language features (pure [ECMAScript](/en-US/docs/Web/JavaScript/Language_Resources), for the most part) includes the following:

- The [JavaScript guide](/en-US/docs/Web/JavaScript/Guide)
- The [JavaScript reference](/en-US/docs/Web/JavaScript/Reference)

If you are new to JavaScript, start with the [guide](/en-US/docs/Web/JavaScript/Guide). Once you have a firm grasp of the fundamentals, you can use the [reference](/en-US/docs/Web/JavaScript/Reference) to get more details on individual objects and language constructs.

## Structure of the reference

In the JavaScript reference you can find the following chapters:

- [Standard built-in objects](/en-US/docs/Web/JavaScript/Reference/Global_Objects)
  - : This chapter documents all the JavaScript standard built-in objects, along with their methods and properties.
- [Statements and declarations](/en-US/docs/Web/JavaScript/Reference/Statements)
  - : JavaScript applications consist of statements with an appropriate syntax. A single statement may span multiple lines. Multiple statements may occur on a single line if each statement is separated by a semicolon. This isn't a keyword, but a group of keywords.
- [Expressions and operators](/en-US/docs/Web/JavaScript/Reference/Operators)
  - : This chapter documents all the JavaScript language operators, expressions and keywords.
- [Functions](/en-US/docs/Web/JavaScript/Reference/Functions)
  - : Chapter about JavaScript functions.
- [Classes](/en-US/docs/Web/JavaScript/Reference/Classes)
  - : Chapter about JavaScript classes introduced in ECMAScript 2015.
- [Errors](/en-US/docs/Web/JavaScript/Reference/Errors)
  - : Chapter about specific errors, exceptions and warnings thrown by JavaScript.
- [New in JavaScript](/en-US/docs/Web/JavaScript/New_in_JavaScript)
  - : Chapter about JavaScript version history.

### More reference pages

- [Deprecated and obsolete features](/en-US/docs/Web/JavaScript/Reference/Deprecated_and_obsolete_features)
- [Lexical grammar](/en-US/docs/Web/JavaScript/Reference/Lexical_grammar)
- [Data types and data structures](/en-US/docs/Web/JavaScript/Data_structures)
